@@ -24,10 +24,10 @@ def all_equal(iterable: Iterable[Any]) -> bool:
     return next(groups, True) and not next(groups, False)
 
 
-Domain = TypeVar('Domain')
+_T = TypeVar('_T')
 
 
-def pairwise(iterable: Iterable[Domain]) -> Iterable[Tuple[Domain, Domain]]:
+def pairwise(iterable: Iterable[_T]) -> Iterable[Tuple[_T, _T]]:
     iterator = iter(iterable)
     element = next(iterator, None)
     for next_element in iterator:
@@ -36,28 +36,21 @@ def pairwise(iterable: Iterable[Domain]) -> Iterable[Tuple[Domain, Domain]]:
 
 
 def polygon_to_oriented_edges_endpoints(polygon: Polygon,
-                                        *,
                                         context: Context
                                         ) -> Iterable[SegmentEndpoints]:
-    yield from contour_to_oriented_edges_endpoints(polygon.border,
-                                                   clockwise=False,
-                                                   context=context)
+    yield from contour_to_oriented_edges_endpoints(polygon.border, context)
     for hole in polygon.holes:
-        yield from contour_to_oriented_edges_endpoints(hole,
-                                                       clockwise=True,
-                                                       context=context)
+        yield from contour_to_oriented_edges_endpoints(hole, context, True)
 
 
 def contour_to_oriented_edges_endpoints(contour: Contour,
-                                        *,
-                                        clockwise: bool = False,
-                                        context: Context
+                                        context: Context,
+                                        clockwise: bool = False
                                         ) -> Iterable[SegmentEndpoints]:
     vertices = contour.vertices
     return (((vertices[index - 1], vertices[index])
              for index in range(len(vertices)))
-            if (to_contour_orientation(contour,
-                                       context=context)
+            if (to_contour_orientation(contour, context)
                 is (Orientation.CLOCKWISE
                     if clockwise
                     else Orientation.COUNTERCLOCKWISE))
@@ -71,9 +64,7 @@ def contour_to_edges_endpoints(contour: Contour) -> Iterable[SegmentEndpoints]:
             for index in range(len(vertices)))
 
 
-def to_contour_orientation(contour: Contour,
-                           *,
-                           context: Context) -> Orientation:
+def to_contour_orientation(contour: Contour, context: Context) -> Orientation:
     vertices = contour.vertices
     index = min(range(len(vertices)),
                 key=vertices.__getitem__)
@@ -104,9 +95,7 @@ def to_segments_x_max(segments: Sequence[Segment]) -> Coordinate:
     return max(max(segment.start.x, segment.end.x) for segment in segments)
 
 
-def shrink_collinear_vertices(vertices: List[Point],
-                              *,
-                              context: Context) -> None:
+def shrink_collinear_vertices(vertices: List[Point], context: Context) -> None:
     index = -len(vertices) + 1
     orienteer = context.angle_orientation
     while index < 0:
@@ -129,7 +118,6 @@ def segments_to_endpoints(segments: Sequence[Segment]
 
 
 def endpoints_to_segments(endpoints: Iterable[SegmentEndpoints],
-                          *,
                           context: Context) -> Sequence[Segment]:
     segment_cls = context.segment_cls
     return [segment_cls(start, end) for start, end in endpoints]
